%Parse incoming communication data from ECG peripheral to extract ECG signal
%lastUnfinishedTail: should be provided from prior function call
%stream: Incoming data, nx2 char array
function [parsedData, unfinishedTail] = parseLiveLogECG_noNotch(lastUnfinishedTail, stream)
    stream = [lastUnfinishedTail; stream];
    unfinishedTail = [];
    parsedData = [];
    eventHead = 1;
%     Fz = [60 120 180 240];
%     Bw = [10 5 5 5];
%     SampFreq = 1800;
    while(isempty(unfinishedTail))
        %Make sure the current packet's HEADER doesn't run off the end of the stream -_-
        if(length(stream(:,1)) - eventHead < 4)
            unfinishedTail = stream(eventHead:end, :);
            break;
        end
        head = stream(eventHead,:); %display head of stream: should ALWAYS be the type. For Event, should be 0x04.
        eventcode=stream(eventHead+1,:); %Display event code: should be 0xFF for received ECG data
        dataLen = hex2dec(stream(eventHead+2,:)); %Specifies the number of bytes remaining in the message
        event = [stream(eventHead+4,:) stream(eventHead+3,:)]; %Extract event.  For an ECG transmission, this will be 0x051B
        %Ignore any packet that's not an ECG transmission and skip to the next packet
        if(~strcmp(event, '051B'))
            eventHead = eventHead+2+dataLen+1;
            continue;
        end
        
        %Now we know we're looking at an ECG transmission; make sure it doesn't run off the end of the stream
        if(eventHead+2+dataLen > length(stream(:,1)))
            unfinishedTail = stream(eventHead:end, :);
        else %Parse ECG transmission
            %Re-assemble transmitted data into 2-byte numbers and transfer
            %to decimal points
            parsedPacketData = [stream(eventHead+12:2:eventHead+2+dataLen,:), stream(eventHead+11:2:eventHead+2+dataLen-1,:)];
            %             decStream = hex2dec(parsedPacketData);
            %             for i = 1:length(Fz)
            %                 [b, a] = iirnotch(2*Fz(i)/SampFreq, 2*Bw(i)/SampFreq);
            %                 decStream = filter(b,a,decStream);
            %             end
            %             fwrite(fid_2,hex2dec(parsedPacketData),'double');
            parsedData = [parsedData; parsedPacketData];
            %             parsedData = [parsedData;decStream];  % Output, notched deciaml data points
        end
        eventHead = eventHead+2+dataLen+1;
    end
end

